footer

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 5, 2023 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model defines a footer TUI component

func New

func New(keymap help.KeyMap) *Model

New creates a new model with a given [help.keymap]

func (*Model) Height

func (m *Model) Height() int

Height returns the current height of the footer

func (*Model) Init

func (*Model) Init() tea.Cmd

Init initialises the footer

func (*Model) Message

func (m *Model) Message(msg string)

Message sets the message within the status bar

func (*Model) Resize

func (m *Model) Resize(width, _ int) bubbles.Model

Resize the dimensions of the footer

func (*Model) Update

func (m *Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update the current footer

func (*Model) View

func (m *Model) View() string

View displays the footer

func (*Model) Width

func (m *Model) Width() int

Width returns the current width of the footer

type ResizedMsg

type ResizedMsg struct{}

ResizedMsg is a message that is sent when the footer has resized due to the help menu expanding and collapsing

Jump to