Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model defines a footer TUI component
type ResizedMsg ¶
type ResizedMsg struct{}
ResizedMsg is a message that is sent when the footer has resized due to the help menu expanding and collapsing
Click to show internal directories.
Click to hide internal directories.