Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model defines a header TUI component
func New ¶
New creates a new model with a given title. Further customization can be achieved by providing additional options:
hdr := New("bubbles", WithDesc("a collection of TUI components"))
type Option ¶
type Option func(*Model)
Option defines options when creating a new model
func WithBorder ¶
func WithBorder() Option
WithBorder provides an option for setting and displaying a border that underlines the header. This border will always be the width of the terminal
func WithDesc ¶
WithDesc provides an option for setting and displaying a description underneath the header title. An empty string is ignored
func WithVersion ¶
WithVersion provides an option for setting and displaying a version alongside the header title. An empty string is ignored
Click to show internal directories.
Click to hide internal directories.